<?php

//Gallery Post Type
add_action('init', 'register_gallery_post_type');
function register_gallery_post_type() {

	register_post_type(
		'wedding_gallery',
		array(
			'labels' => array(
				'name' => __('Gallery','wedding'),
				'singular_name' => __('Album','wedding')
			),
			'public' => true,
			'has_archive' => true,
			'rewrite' => array('slug' => 'gallery-items'),
			'supports' => array('title', 'thumbnail', 'editor','comments'),
			'menu_icon' => get_template_directory_uri() . '/includes/gallery/gallery.png'
		)
	);
	
}
//Gallery Post Type

//Gallery thumbnail size based on the number of columns
add_action( 'after_setup_theme', 'gallery_thumbnail_sizes' );
function gallery_thumbnail_sizes() {
	add_image_size( 'gallery-one-half', 320, 320,true );
	add_image_size( 'gallery-one-third', 226, 226, true );
	add_image_size( 'gallery-one-fourth', 164, 164, true );
}

function wedding_gallery_thumbnail_size() {
	$columns = wedding_field('gallery_columns');
	
	if ($columns == 4) $content = 'gallery-one-fourth';
	if ($columns == 3) $content = 'gallery-one-third';
	if ($columns == 2) $content = 'gallery-one-half';
	
	return $content;
}
//Gallery thumbnail size based on the number of columns

//Menu current class if its single gallery page
function gallery_change_page_menu_classes($menu){
	global $post;
	if (get_post_type($post) == 'wedding_gallery')
	{
		$gallery_parent = '';
		
		$gallery_parent = get_pages(array(
			'meta_key' => '_wp_page_template',
			'meta_value' => 'page-templates/gallery.php',
			'hierarchical' => 0
		));
		
		$gallery_parent = $gallery_parent[0]->ID;
		global $wpdb;
		$gallery_parent = $wpdb->get_var( 'SELECT post_id FROM '.$wpdb->postmeta.' WHERE meta_key="_menu_item_object_id" AND meta_value="'.$gallery_parent.'"' );
		$menu = str_replace( 'current_page_parent', '', $menu );
		$menu = str_replace( 'menu-item-'.$gallery_parent.'" class="', 'menu-item-'.$gallery_parent.'" class="current_page_parent ', $menu );
	}
	return $menu;
}
add_filter( 'wp_nav_menu', 'gallery_change_page_menu_classes', 0 );
//Menu current class if its single gallery page

//Get gallery homepage link
function get_gallery_homepage() {
	$pages = get_pages(array(
		'meta_key' => '_wp_page_template',
		'meta_value' => 'page-templates/gallery.php'
	));

	$link = get_permalink($pages[0]->ID);	

	return $link;
}
//Get gallery homepage link

//Custom metabox for uploading and managing gallery images
add_action('admin_init', 'register_gallery_images_field');
add_action('save_post', 'save_gallery_images_meta',10,2);

function register_gallery_images_field() {
	add_meta_box('gallery_images_meta', 'Slider', 'gallery_images_meta_callback', 'wedding_gallery','normal','high');
	wp_register_style('wedding_gallery_admin_css', get_template_directory_uri().'/includes/gallery/gallery.css');
}

function gallery_images_meta_callback() {
	global $post;
	$custom = get_post_custom($post->ID);

	$gallery_images = '';
	if (isset($custom['gallery_images'][0])) $gallery_images = $custom['gallery_images'][0];
	
	wp_nonce_field( basename( __FILE__ ), 'gallery_images_meta_nonce' );
	
	if ( ! did_action( 'wp_enqueue_media' ) )
    wp_enqueue_media();

    wp_register_script('wedding_gallery_admin_js', get_template_directory_uri().'/includes/gallery/gallery.js');
    wp_enqueue_style('wedding_gallery_admin_css');
    
    $gallery_translation_array = array(
    	'select_title' => __('Pick or upload images to the gallery', 'wedding'), 
    	'select_button' => __('Insert', 'wedding'), 
    	'edit_title' => __('Edit this image', 'wedding'),
    	'edit_button' => __('Update', 'wedding'),
    	'edit' => __('Edit', 'wedding'),
    	'delete' => __('Delete', 'wedding')
   	);
    wp_localize_script( 'wedding_gallery_admin_js', 'gallery_strings', $gallery_translation_array );

    wp_enqueue_script( 'wedding_gallery_admin_js' );
	
	?>
	
	<div style="display:none;" id="gallery_images" <?php if(!$gallery_images):?>class="no_images"<?php endif; ?>>
		<?php if($gallery_images): $gallery_images = unserialize($gallery_images); foreach($gallery_images as $image): ?>
		<?php $thumb = wp_get_attachment_thumb_url( $image ); ?>
		<?php $title = get_the_title( $image ); ?>
		<div class="image">
			<input type="text" name="gallery_images[]" value="<?php echo $image; ?>" />
			<img src="<?php echo $thumb; ?>" />
			<a href="#" class="edit icon-pencil"><?php _e('Edit','wedding'); ?></a>
			<a href="#" class="delete icon-minus-circled"><?php _e('Delete','wedding'); ?></a>
			<strong><?php echo $title; ?></strong>
		</div>
		<?php endforeach; endif; ?>
		<a href="#" id="upload_gallery_images" class="icon-picture">Add new image</a>
		<div class="clear"></div>
	</div>

	<?php
}

function save_gallery_images_meta($post_id, $post) {
	global $post;

	if ( !isset( $_POST['gallery_images_meta_nonce'] ) || !wp_verify_nonce( $_POST['gallery_images_meta_nonce'], basename( __FILE__ ) ) )
		return $post_id;

	$post_type = get_post_type_object( $post->post_type );

	if ( !current_user_can( $post_type->cap->edit_post, $post_id ) )
		return $post_id;

	$post_meta = array();
	if (isset($_POST['gallery_images'])) $post_meta['gallery_images'] = $_POST['gallery_images'];

	foreach ($post_meta as $key => $value) {
		$new_meta_value = ( isset( $value ) ? $value : '' );
		$meta_key = $key;
		$meta_value = get_post_meta( $post_id, $meta_key, true );
		if ( $new_meta_value && '' == $meta_value )
			add_post_meta( $post_id, $meta_key, $new_meta_value, true );
		elseif ( $new_meta_value && $new_meta_value != $meta_value )
			update_post_meta( $post_id, $meta_key, $new_meta_value );
		elseif ( '' == $new_meta_value && $meta_value )
			delete_post_meta( $post_id, $meta_key, $meta_value );
	}

}
//Custom metabox for uploading and managing gallery images

//Get number of photos inside an album
function get_gallery_photos_count($gallery_id = 0) {
	if (!$gallery_id) $gallery_id = get_the_ID();
	$photos = get_post_meta($gallery_id, 'gallery_images', true);
	if (is_array($photos)) {
		$photos = sprintf( _n( '%d photo', '%d photos', sizeof($photos), 'wedding' ), sizeof($photos) );

	} else {
		$photos = __('no photos','wedding');
	}
	return $photos;
}
//Get number of photos inside an album

//Get random photo from an album
function get_random_photo($gallery_id = 0) {
	if (!$gallery_id) $gallery_id = get_the_ID();
	$photos = get_post_meta($gallery_id, 'gallery_images', true);
	
	if (count($photos) > 1) {
		$max = count($photos)-1;
		$photo = $photos[rand(0, $max)]; 
		$thumbnail_id = get_post_thumbnail_id($gallery_id);
		
		if ($thumbnail_id != $photo && count($photos) > 1){ return $photo; }
	}
}
//Get number of photos inside an album

//Gallery shortcode generator metabox
add_action('admin_init', 'register_gallery_shortcode_generator');

function register_gallery_shortcode_generator() {
	add_meta_box('gallery_shortcode_generator', __('Shortcode Generator','wedding'), 'gallery_shortcode_generator', 'wedding_gallery', 'side');
}

function gallery_shortcode_generator() {
	global $post;
	$id = $post->ID;	
	?>
	<p class="shortcode_gen_radios" id="<?php echo $id; ?>">
		<label>
			<input type="radio" name="shortcode_type" value="gallery" checked="checked" />
			<?php _e('Gallery','wedding'); ?>
		</label>
		<label>
			<input type="radio" name="shortcode_type" value="scrollable" />
			<?php _e('Scrollable','wedding'); ?>
		</label>
		<label>
			<input type="radio" name="shortcode_type" value="summary" />
			<?php _e('Summary','wedding'); ?>
		</label>
	</p>
	<p class="shortcode_gen_title">
		<label>
			<input type="checkbox" name="show_title" value="title" />
			<?php _e('Show title','wedding'); ?>
		</label>
		<label>
			<input type="checkbox" name="show_description" value="description" />
			<?php _e('Show description','wedding'); ?>
		</label>
	</p>
	<p class="shortcode_gen_code"><textarea name="gallery_shortcode" rows="5" style="width:100%"></textarea></p>
	<?php
}
//Gallery shortcode generator metabox

//Gallery shortcodes
add_shortcode( 'wedding_gallery', 'wedding_gallery_shortcode' );
function wedding_gallery_shortcode( $atts, $content=null ){
	extract(shortcode_atts(array(
		'id' => '',
		'type' => '',
		'title' => false,
		'description' => false
	), $atts));
	$gallery = '';
	$class = '';
	$photos = get_post_meta($id, 'gallery_images', true);
	
	if ($type == 'scrollable') {
		wp_enqueue_script('jquery-elastislide-js');
		$class = ' scrollable';
	}
	
	$gallery .= '<div class="wedding_gallery">';
	
	if ($title) $gallery .= '<h2>'.get_the_title($id).'</h2>';
	if ($description) $gallery .= apply_filters('the_content', get_post_field('post_content', $id));
	
	if ($photos && $type != 'summary'):
	
		$gallery .= '<ul class="album'.$class.'">';
	
		foreach ($photos as $photo):
			$gallery .= '<li>';
			
				$full = wp_get_attachment_url( $photo );
				$thumb = wp_get_attachment_image( $photo );
				$title = get_the_title( $photo );
			
				$gallery .= '<a href="'.$full.'" rel="fancybox" title="'.$title.'">';
					$gallery .= $thumb;
				$gallery .= '</a>';
			
			$gallery .= '</li>';
		endforeach;
		
			$gallery .= '<li class="clear"></li>';
		
		$gallery .= '</ul>';
	
	endif;
	
	if ($type == 'summary') {
		$gallery .= '<a href="'.get_permalink($id).'" class="gallery-summary">';
			$gallery .= get_the_post_thumbnail($id,'thumbnail');
			$gallery .= '<strong>'.get_the_title( $id ).'</strong>';
			$gallery .= '<em>'.get_gallery_photos_count( $id ).'</em>';
		$gallery .= '</a>';
	}
	
	$gallery .= '<div class="clear"></div></div>';
	
	
	return $gallery;
}
//Gallery shortcodes

//Gallery Custom Table and another modifications
function gallery_custom_columns($columns) {
	$columns = array(
		'cb'	 	=> '<input type="checkbox" />',
		'thumbnail' 	=> __('Thumbnail','wedding'),
		'title' 	=> __('Album','wedding'),
		'images'	=>	__('Number of Photos','wedding'),
		'shortcode'	=>	__('Shortcode','wedding'),
		'date'		=>	__('Date','wedding'),
	);
	return $columns;
}

function gallery_custom_columns_data($column) {
	global $post;
	
	wp_enqueue_style('wedding_gallery_admin_css');
	
	if ($column == 'thumbnail') {
		echo get_the_post_thumbnail($post->ID,'thumbnail');
		echo wp_get_attachment_image( get_random_photo($post->ID) );
		echo wp_get_attachment_image( get_random_photo($post->ID) );
	}
	if ($column == 'images') {
		echo get_gallery_photos_count($post->ID);
	}
	if ($column == 'shortcode') {
		echo '<input type="text" value="[wedding_gallery id=&quot;'.$post->ID.'&quot;]" readonly />';
	}
}
 
add_action("manage_wedding_gallery_posts_custom_column", "gallery_custom_columns_data");
add_filter("manage_edit-wedding_gallery_columns", "gallery_custom_columns");
//Gallery Custom Table and another modifications

?>