<?php 

/* Theme Options */
function options_typography_get_os_fonts() {
	// OS Font Defaults
	$os_faces = array(
		'Arial, sans-serif' => 'Arial',
		'"Avant Garde", sans-serif' => 'Avant Garde',
		'Cambria, Georgia, serif' => 'Cambria',
		'Copse, sans-serif' => 'Copse',
		'Garamond, "Hoefler Text", Times New Roman, Times, serif' => 'Garamond',
		'Georgia, serif' => 'Georgia',
		'"Helvetica Neue", Helvetica, sans-serif' => 'Helvetica Neue',
		'Tahoma, Geneva, sans-serif' => 'Tahoma'
	);
	return $os_faces;
}

function options_typography_get_google_fonts() {
	// Google Font Defaults
	$google_faces = array(
		'Arvo, serif' => 'Arvo',
		'Balthazar, seif' => 'Balthazar',
		'Copse, sans-serif' => 'Copse',
		'Droid Sans, sans-serif' => 'Droid Sans',
		'Droid Serif, serif' => 'Droid Serif',
		'Lobster, cursive' => 'Lobster',
		'Nobile, sans-serif' => 'Nobile',
		'Open Sans, sans-serif' => 'Open Sans',
		'Oswald, sans-serif' => 'Oswald',
		'Pacifico, cursive' => 'Pacifico',
		'Rokkitt, serif' => 'Rokkit',
		'PT Sans, sans-serif' => 'PT Sans',
		'Quattrocento, serif' => 'Quattrocento',
		'Raleway, cursive' => 'Raleway',
		'Ubuntu, sans-serif' => 'Ubuntu',
		'Yanone Kaffeesatz, sans-serif' => 'Yanone Kaffeesatz',
		'Sanchez, serif' => 'Sanchez'
	);
	return $google_faces;
}

class Wedding_Options {

	private $sections;
	private $checkboxes;
	private $settings;

	public function __construct() {

		$this->checkboxes = array();
		$this->settings = array();
		$this->get_options_settings();

		$this->sections['general']      = __( 'General Settings', 'wedding' );
		$this->sections['advanced']   = __( 'Advanced', 'wedding' );
		$this->sections['gallery']        = __( 'Gallery', 'wedding' );
		$this->sections['social']        = __( 'Social Icons', 'wedding' );

		add_action( 'admin_menu', array( &$this, 'add_pages' ) );
		add_action( 'admin_init', array( &$this, 'register_settings' ) );

		if ( ! get_option( 'wedding_options' ) )
			$this->initialize_settings();
	}

	public function add_pages() {
		$admin_page = add_theme_page( __( 'Theme Options', 'wedding' ), __( 'Theme Options', 'wedding' ), 'manage_options', 'wedding-options', array( &$this, 'display_page' ) );
		add_action( 'admin_print_scripts-' . $admin_page, array( &$this, 'scripts' ) );
	}

	public function create_setting( $args = array() ) {

		$defaults = array(
			'id'      => 'default_field',
			'title'   => __( 'Default Field', 'wedding' ),
			'desc'    => __( 'This is a default description.', 'wedding' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'general',
			'choices' => array(),
			'class'   => ''
		);

		extract( wp_parse_args( $args, $defaults ) );

		$field_args = array(
			'type'      => $type,
			'id'        => $id,
			'desc'      => $desc,
			'std'       => $std,
			'choices'   => $choices,
			'label_for' => $id,
			'class'     => $class
		);

		if ( $type == 'checkbox' )
			$this->checkboxes[] = $id;

		add_settings_field( $id, $title, array( $this, 'display_setting' ), 'wedding-options', $section, $field_args );
	}

	public function display_page() { ?>
	
		<div class="wrap" style="display:none">
			<div class="icon32" id="icon-options-general"></div>
			<h2><?php _e( 'Theme Options', 'wedding' ); ?></h2>
			<?php if ( isset( $_GET['settings-updated'] ) && $_GET['settings-updated'] == true ): ?>
				<div class="updated fade"><p><?php _e( 'Theme options updated.', 'wedding' ); ?></p></div>
			<?php endif; ?>
			
			<?php
			$code = get_option('wedding-purchase-code', '');
			$validity = get_option('wedding-validated', '0');
			?>
			<form action="<?php echo $_SERVER['REQUEST_URI'] ?>" method="post" class="wedding-auto-update" id="wedding_options" style="display:none;" <?php if($validity == '1'): ?>style="display:none;"<?php endif; ?>>
				<input type="hidden" name="action" value="wedding_verify_purchase_code">
				<div class="ui-tabs-panel ui-widget-content ui-corner-bottom">
					<h3><?php _e('Auto-updates', 'wedding') ?></h3>
					<table class="form-table">
						<tbody>
							<tr valign="top">
								<td><?php _e('Purchase code', 'wedding') ?></td>
								<td class="desc">
									<input type="text" name="purchase_code" size="40" value="<?php echo $code ?>" placeholder="bc8e2b24-3f8c-4b21-8b4b-90d57a38e3c7"><br>
									<span class="description"><?php _e('To receive auto-updates, you need to enter your item purchase code. You can find it on your ThemeForest downloads page, just click on the "Licence Certificate" button of the corresponding item. This will download a text file which contains your purchase code.', 'wedding') ?></span>
								</td>
							</tr>
						</tbody>
						<tfoot>
							<tr>
								<td colspan="2">
									<button class="button"><?php _e('Save Changes', 'wedding') ?></button>
									<span style="<?php echo ($validity == '0' && $code != '') ? 'color: #c33219;' : 'color: #4b982f'?>">
										<?php
											if($validity == '1') {
												_e('Thank you for purchasing Wedding. You successfully validated your purchase code for auto-updates.', 'wedding');
											} else if($code != '') {
												_e("Your purchase code doesn't appear to be valid. Please make sure that you entered your purchase code correctly.", "wedding");
											}
										?>
									</span>
								</td>
							</tr>
						</tfoot>
					</table>
				</div>
			</form>
			
			<form action="options.php" method="post" id="wedding_options">
				<?php settings_fields( 'wedding_options' ); ?>
				<div class="ui-tabs">
					<ul class="ui-tabs-nav">
						<?php foreach ( $this->sections as $section_slug => $section ): ?>
						<li><a href="#<?php echo $section_slug; ?>" class="<?php echo $section_slug; ?>"><small></small><span><?php echo $section; ?></span></a></li>
						<?php endforeach; ?>
					</ul>
					<?php do_settings_sections( $_GET['page'] ); ?>
				</div>
				<p class="submit"><input name="Submit" type="submit" class="button-primary" value="'<?php _e( 'Save Changes', 'wedding' ); ?>" /></p>
			</form>
		</div>
	
	
	<?php
	}

	public function display_section() {
		// code
	}

	public function display_setting( $args = array() ) {

		extract( $args );

		$options = get_option( 'wedding_options' );

		if ( ! isset( $options[$id] ) && $type != 'checkbox' )
			$options[$id] = $std;
		elseif ( ! isset( $options[$id] ) )
			$options[$id] = 0;

		$field_class = '';
		if ( $class != '' )
			$field_class = ' ' . $class;

		switch ( $type ) {

			case 'heading':
				echo '<h4 class="heading"><span class="icon'.$field_class.'">' . $desc . '</span></h4>';
				break;

			case 'checkbox':

				echo '<input class="checkbox' . $field_class . '" type="checkbox" id="' . $id . '" name="wedding_options[' . $id . ']" value="1" ' . checked( $options[$id], 1, false ) . ' /> <label for="' . $id . '">' . $desc . '</label>';

				break;

			case 'select':
				echo '<select class="select' . $field_class . '" name="wedding_options[' . $id . ']">';

				foreach ( $choices as $value => $label )
					echo '<option value="' . esc_attr( $value ) . '"' . selected( $options[$id], $value, false ) . '>' . $label . '</option>';

				echo '</select>';

				if ( $desc != '' )
					echo '<br /><span class="description">' . $desc . '</span>';

				break;

			case 'radio':
				$i = 0;
				foreach ( $choices as $value => $label ) {
					echo '<input class="radio' . $field_class . '" type="radio" name="wedding_options[' . $id . ']" id="' . $id . $i . '" value="' . esc_attr( $value ) . '" ' . checked( $options[$id], $value, false ) . '> <label for="' . $id . $i . '">' . $label . '</label>';
					if ( $i < count( $options ) - 1 )
						echo '<br />';
					$i++;
				}

				if ( $desc != '' )
					echo '<br /><span class="description">' . $desc . '</span>';

				break;

			case 'textarea':
				echo '<textarea class="' . $field_class . '" id="' . $id . '" name="wedding_options[' . $id . ']" placeholder="' . $std . '" rows="8" cols="70">' . wp_htmledit_pre( $options[$id] ) . '</textarea>';

				if ( $desc != '' )
					echo '<br /><span class="description">' . $desc . '</span>';

				break;

			case 'wysiwyg':

				echo wp_editor( $options[$id], 'wedding_options[' . $id . ']', $settings = array('wpautop') );

				if ( $desc != '' )
					echo '<br /><span class="description">' . $desc . '</span>';

				break;

			case 'password':
				echo '<input class="regular-text' . $field_class . '" type="password" id="' . $id . '" name="wedding_options[' . $id . ']" value="' . esc_attr( $options[$id] ) . '" />';

				if ( $desc != '' )
					echo '<br /><span class="description">' . $desc . '</span>';

				break;

			case 'text':
			default:
		 		echo '<input class="regular-text' . $field_class . '" type="text" id="' . $id . '" name="wedding_options[' . $id . ']" placeholder="' . $std . '" value="' . esc_attr( $options[$id] ) . '" />';

		 		if ( $desc != '' )
		 			echo '<br /><span class="description">' . $desc . '</span>';

		 		break;

		 	case 'colorpicker':
			default:
		 		echo '<input class="regular-text color' . $field_class . '" type="text" id="' . $id . '" name="wedding_options[' . $id . ']" placeholder="' . $std . '" value="' . esc_attr( $options[$id] ) . '" />';
		 		if ( $desc != '' )
		 			echo '<br /><span class="description">' . $desc . '</span>';

		 		break;

		 	case 'image':
			default:

		 		echo '<input class="regular-text' . $field_class . '" type="text" id="' . $id . '" name="wedding_options[' . $id . ']" placeholder="' . $std . '" value="' . esc_attr( $options[$id] ) . '" />';

		 		echo '<a href="#" class="button-secondary upload_image">Upload Image</a>';

		 		if ( $desc != '' )
		 			echo '<span class="description description_image">' . $desc . '</span>';

				if (esc_attr( $options[$id] ) != '') {
					echo '<div class="clear"></div><div class="image_sample"><a href="#">x</a><img src="'.esc_attr( $options[$id] ).'" /></div>';
				}


		 		break;
		 		
		 	case 'sidebars':
			default:
			
				if($options[$id]) {
					foreach ( $options[$id] as $sidebar ) {
						echo '<p class="custom_sidebar_row">';
			 			echo '<input class="regular-text' . $field_class . '" type="text" id="' . $id . '" name="wedding_options[' . $id . '][]" placeholder="' . $std . '" value="' . esc_attr( $sidebar ) . '" />';
			 			echo '<a href="#" class="remove"></a>';
			 			echo '</p>';

					}
				} else {
					echo '<p class="custom_sidebar_row">';
		 			echo '<input class="regular-text' . $field_class . '" type="text" id="' . $id . '" name="wedding_options[' . $id . '][]" placeholder="' . $std . '" value="' . esc_attr( $options[$id] ) . '" />';
		 			echo '<a href="#" class="remove"></a>';
		 			echo '</p>';
				}
				
		 		if ( $desc != '' )
		 			echo '<a href="#" class="add_sidebar">Add sidebar</a><br /><span class="description">' . $desc . '</span>';

		 		break;
		 		
		 	case 'font':
				echo '<select class="select font-select' . $field_class . '" name="wedding_options[' . $id . ']">';


				$typography_mixed_fonts = array_merge( options_typography_get_os_fonts() , options_typography_get_google_fonts() );
				asort($typography_mixed_fonts);

				echo '<option value=""' . selected( $options[$id], $value, false ) . '></option>';

				foreach ( $typography_mixed_fonts as $value => $label )
					echo '<option value="' . esc_attr( $value ) . '"' . selected( $options[$id], $value, false ) . '>' . $label . '</option>';

				echo '</select>';

				if ( $desc != '' )
					echo '<br /><span class="description">' . $desc . '</span>';

				break;

		}

	}

	public function get_options_settings() {

		/* General Settings
		===========================================*/
		
		$this->settings['layout'] = array(
			'section' => 'general',
			'title'   => __( 'Layout', 'wedding' ),
			'type'    => 'select',
			'std'     => 'full-width',
			'choices' => array(
				'full-width' => 'Full Width',
				'boxed' => 'Boxed'
			),
			'class'   => 'settings_layout'
		);
		
		$this->settings['header_logo'] = array(
			'section' => 'general',
			'title'   => __( 'Logo', 'wedding' ),
			'desc'    => __( 'The main logo in the header(also used for the WordPress login screen)', 'wedding' ),
			'type'    => 'image',
			'std'     => ''
		);
		
		$this->settings['logo_center'] = array(
			'section' => 'general',
			'title'   => __( 'Logo Layout', 'wedding' ),
			'desc'    => __( 'Center the logo', 'wedding' ),
			'type'    => 'checkbox',
			'std'     => ''
		);
		
		$this->settings['primary_color'] = array(
			'title'   => __( 'Primary Color', 'wedding' ),
			'desc'    => __( 'Buttons, links, hover on menu and section titles', 'wedding' ),
			'std'     => '#eb7b54',
			'type'    => 'colorpicker',
			'section' => 'general'
		);
		
		$this->settings['secondary_color'] = array(
			'title'   => __( 'Secondary Color', 'wedding' ),
			'desc'    => __( 'Dividers, borders, buttons, blockquote etc...', 'wedding' ),
			'std'     => '#b1b0ac',
			'type'    => 'colorpicker',
			'section' => 'general'
		);
		
		$this->settings['text_color'] = array(
			'title'   => __( 'Text Color', 'wedding' ),
			'desc'    => '',
			'std'     => '#6b6a67',
			'type'    => 'colorpicker',
			'section' => 'general'
		);
		
		$this->settings['title_color'] = array(
			'title'   => __( 'Title Color', 'wedding' ),
			'desc'    => '',
			'std'     => '#45433e',
			'type'    => 'colorpicker',
			'section' => 'general'
		);
		
		$this->settings['box_color'] = array(
			'title'   => __( 'Box Color', 'wedding' ),
			'desc'    => '',
			'std'     => '#ffffff',
			'type'    => 'colorpicker',
			'section' => 'general'
		);
		
		$this->settings['box_text_color'] = array(
			'title'   => __( 'Box Text Color', 'wedding' ),
			'desc'    => __( 'Text color inside the boxes', 'wedding' ),
			'std'     => '',
			'type'    => 'colorpicker',
			'section' => 'general'
		);
		
		$this->settings['section_title_color'] = array(
			'title'   => __( 'Section Title Color', 'wedding' ),
			'desc'    => '',
			'std'     => '',
			'type'    => 'colorpicker',
			'section' => 'general'
		);
		
		$this->settings['body_bg_color'] = array(
			'title'   => __( 'Background Color', 'wedding' ),
			'desc'    => __( 'Body background color', 'wedding' ),
			'std'     => '#f9f8f5',
			'type'    => 'colorpicker',
			'section' => 'general'
		);
		
		$this->settings['body_bg_img'] = array(
			'section' => 'general',
			'title'   => __( 'Background Image', 'wedding' ),
			'desc'    => __( 'Body background image', 'wedding' ),
			'type'    => 'image',
			'std'     => ''
		);
		
		$this->settings['body_bg_full'] = array(
			'section' => 'general',
			'title'   => __( 'Stretch the background image full-screen', 'wedding' ),
			'desc'    => '',
			'type'    => 'checkbox',
			'std'     => ''
		);
		
		$this->settings['body_bg_props'] = array(
			'section' => 'general',
			'title'   => __( 'Background Properties', 'wedding' ),
			'desc'    => __( 'CSS properties attached to the background. If you want a fixed background, use "no-repeat" for example.', 'wedding' ),
			'type'    => 'text',
			'std'     => ''
		);
		
		$this->settings['page_bg_color'] = array(
			'title'   => __( 'Page Container Background Color', 'wedding' ),
			'desc'    => __( 'Background of the page container, when the layout is boxed', 'wedding' ),
			'std'     => '',
			'type'    => 'colorpicker',
			'section' => 'general'
		);
		
		$this->settings['favicon'] = array(
			'section' => 'general',
			'title'   => __( 'Favicon', 'wedding' ),
			'desc'    => __( '16px Favicon', 'wedding' ),
			'type'    => 'image',
			'std'     => ''
		);
		
		$this->settings['text'] = array(
			'section' => 'general',
			'title'   => '', // Not used for headings.
			'desc'    => 'Text',
			'type'    => 'heading',
			'class'   => 'text'
		);
		
		$this->settings['copyright_text'] = array(
			'title'   => __( 'Copyright text', 'wedding' ),
			'desc'    => __( 'This content appears in the footer as the copyright text. Use the #YEAR# variable to display the current year automatically. You can also use shortcodes.', 'wedding' ),
			'std'     => __( 'Copyright #YEAR# - ALl rights reserved', 'wedding' ),
			'type'    => 'textarea',
			'section' => 'general'
		);
		
		$this->settings['body_font'] = array(
			'title'   => __( 'Default font', 'wedding' ),
			'desc'    => __( 'Primary font for the content and the H1, H2... titles. My suggestion is to choose a sans-serif font type with normal, semi-bold, bold and extrabold variations, like Open Sans.', 'wedding' ),
			'std'     => '',
			'type'    => 'font',
			'section' => 'general'
		);
		
		$this->settings['header_font'] = array(
			'title'   => __( 'Header titles font', 'wedding' ),
			'desc'    => __( 'Font type for H1, H2, H3, H4 and H5 titles. By default its the Primary font, so this field is not required.', 'wedding' ),
			'std'     => '',
			'type'    => 'font',
			'section' => 'general'
		);
		
		$this->settings['section_font'] = array(
			'title'   => __( 'Section title font', 'wedding' ),
			'desc'    => __( 'Font type for the section titles. My suggestion is to use a serif font type.', 'wedding' ),
			'std'     => '',
			'type'    => 'font',
			'section' => 'general'
		);
		
		$this->settings['menu_font'] = array(
			'title'   => __( 'Menu font', 'wedding' ),
			'desc'    => __( 'Font type for main navigation', 'wedding' ),
			'std'     => '',
			'type'    => 'font',
			'section' => 'general'
		);
		
		$this->settings['font_size'] = array(
			'title'   => __( 'Font size', 'wedding' ),
			'desc'    => __( 'Default font size, everything else is calculated from this value. Default is 12px', 'wedding' ),
			'std'     => '14px',
			'type'    => 'text',
			'section' => 'general'
		);
		
		$this->settings['line_height'] = array(
			'title'   => __( 'Line height', 'wedding' ),
			'desc'    => __( 'Default line height, everything else is calculated from this value. Default is 20px', 'wedding' ),
			'std'     => '22px',
			'type'    => 'text',
			'section' => 'general'
		);
		
		$this->settings['everythingelse'] = array(
			'section' => 'general',
			'title'   => '', // Not used for headings.
			'desc'    => __( 'Everything Else', 'wedding' ),
			'type'    => 'heading',
			'class'   => 'everythingelse'
		);
		
		$this->settings['blog_layout'] = array(
			'section' => 'general',
			'title'   => __( 'Blog Layout', 'wedding' ),
			'desc'    => __( 'Sidebar layout on the blog pages (main blog list, archive, category etc...).', 'wedding' ),
			'type'    => 'select',
			'std'     => 'left-sidebar',
			'choices' => array(
				'default' => 'Default Template',
				'left-sidebar' => 'Left Sidebar',
				'right-sidebar' => 'Right Sidebar'
			),
			'class'   => 'settings_layout'
		);
		
		$this->settings['ajax_pagination'] = array(
			'section' => 'general',
			'title'   => __( 'Ajax Pagination', 'wedding' ),
			'desc'    => __( 'Use ajax to load more posts on the same page.', 'wedding' ),
			'type'    => 'checkbox',
			'std'     => '1'
		);
		
		$this->settings['custom_css'] = array(
			'title'   => __( 'Custom Styles', 'wedding' ),
			'desc'    => __( 'Enter any custom CSS here to apply it to your theme.', 'wedding' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'advanced',
			'class'   => 'code'
		);
		
		$this->settings['custom_js'] = array(
			'title'   => __( 'Custom Scripts', 'wedding' ),
			'desc'    => __( 'Enter any custom JS here to apply it to your theme. You can enter the Google Analytics code here for example.', 'wedding' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'advanced',
			'class'   => 'code'
		);
		
		$this->settings['sidebars'] = array(
			'title'   => __( 'Register Custom Sidebars', 'wedding' ),
			'desc'    => __( 'You can register multiple sidebars and you can choose these sidebars for the left or right column page template.', 'wedding' ),
			'std'     => '',
			'type'    => 'sidebars',
			'section' => 'advanced',
			'class'   => 'repeater'
		);

		$this->settings['gallery_columns'] = array(
			'section' => 'gallery',
			'title'   => __( 'Gallery columns', 'wedding' ),
			'desc'    => __( 'How many columns do you want on the gallery page?', 'wedding' ),
			'type'    => 'radio',
			'std'     => '4',
			'choices' => array(
				'2' => '2 Columns',
				'3' => '3 Columns',
				'4' => '4 Columns'
			)
		);
		
		$this->settings['gallery_per_page'] = array(
			'title'   => __( 'Items per page', 'wedding' ),
			'desc'    => __( 'How many items do you want to display on one page?', 'wedding' ),
			'std'     => '12',
			'type'    => 'text',
			'section' => 'gallery'
		);
		
		$this->settings['gallery_album_target'] = array(
			'title'   => __( 'Show albums in', 'wedding' ),
			'desc'    => __( 'When you click on an album, you can choose to be opened in a new window or in a lightbox', 'wedding' ),
			'type'    => 'radio',
			'std'     => 'fancybox',
			'choices' => array(
				'fancybox' => 'Fancybox',
				'page' => 'Regular page'
			),
			'section' => 'gallery'
		);
		
		$this->settings['gallery_photo_link'] = array(
			'title'   => __( 'Attachment link below photos', 'wedding' ),
			'desc'    => '',
			'type'    => 'checkbox',
			'std'     => '',
			'section' => 'gallery'
		);
				
		$this->settings['social_href_github'] = array(
			'section' => 'social',
			'title'   => 'Github',
			'type'    => 'text',
			'std'     => '',
			'desc'    => __( 'The default values for the social icons. So if you use the social icon shortcode, you dont have to manually insert the href attribute for the link(but you can overwrite it of course)', 'wedding' )
		);
		$this->settings['social_href_flickr'] = array(
			'section' => 'social',
			'title'   => 'Flickr',
			'type'    => 'text',
			'std'     => '',
			'desc'    => ''
		);
		$this->settings['social_href_vimeo'] = array(
			'section' => 'social',
			'title'   => 'Vimeo',
			'type'    => 'text',
			'std'     => '',
			'desc'    => ''
		);
		$this->settings['social_href_twitter'] = array(
			'section' => 'social',
			'title'   => 'Twitter',
			'type'    => 'text',
			'std'     => '',
			'desc'    => ''
		);
		$this->settings['social_href_facebook'] = array(
			'section' => 'social',
			'title'   => 'Facebook',
			'type'    => 'text',
			'std'     => '',
			'desc'    => ''
		);
		$this->settings['social_href_gplus'] = array(
			'section' => 'social',
			'title'   => 'Google+',
			'type'    => 'text',
			'std'     => '',
			'desc'    => ''
		);
		$this->settings['social_href_pinterest'] = array(
			'section' => 'social',
			'title'   => 'Pinterest',
			'type'    => 'text',
			'std'     => '',
			'desc'    => ''
		);
		$this->settings['social_href_tumblr'] = array(
			'section' => 'social',
			'title'   => 'Tumblr',
			'type'    => 'text',
			'std'     => '',
			'desc'    => ''
		);
		$this->settings['social_href_linkedin'] = array(
			'section' => 'social',
			'title'   => 'LinkedIn',
			'type'    => 'text',
			'std'     => '',
			'desc'    => ''
		);
		$this->settings['social_href_dribbble'] = array(
			'section' => 'social',
			'title'   => 'Dribbble',
			'type'    => 'text',
			'std'     => '',
			'desc'    => ''
		);
		$this->settings['social_href_stumbleupon'] = array(
			'section' => 'social',
			'title'   => 'Stumbleupon',
			'type'    => 'text',
			'std'     => '',
			'desc'    => ''
		);
		$this->settings['social_href_lastfm'] = array(
			'section' => 'social',
			'title'   => 'Last.fm',
			'type'    => 'text',
			'std'     => '',
			'desc'    => ''
		);
		$this->settings['social_href_rdio'] = array(
			'section' => 'social',
			'title'   => 'Rdio',
			'type'    => 'text',
			'std'     => '',
			'desc'    => ''
		);
		$this->settings['social_href_spotify'] = array(
			'section' => 'social',
			'title'   => 'Spotify',
			'type'    => 'text',
			'std'     => '',
			'desc'    => ''
		);
		$this->settings['social_href_qq'] = array(
			'section' => 'social',
			'title'   => 'QQ',
			'type'    => 'text',
			'std'     => '',
			'desc'    => ''
		);
		$this->settings['social_href_instagram'] = array(
			'section' => 'social',
			'title'   => 'Instagram',
			'type'    => 'text',
			'std'     => '',
			'desc'    => ''
		);
		$this->settings['social_href_dropbox'] = array(
			'section' => 'social',
			'title'   => 'Dropbox',
			'type'    => 'text',
			'std'     => '',
			'desc'    => ''
		);
		$this->settings['social_href_evernote'] = array(
			'section' => 'social',
			'title'   => 'Evernote',
			'type'    => 'text',
			'std'     => '',
			'desc'    => ''
		);
		$this->settings['social_href_flattr'] = array(
			'section' => 'social',
			'title'   => 'Flattr',
			'type'    => 'text',
			'std'     => '',
			'desc'    => ''
		);
		$this->settings['social_href_skype'] = array(
			'section' => 'social',
			'title'   => 'Skype',
			'type'    => 'text',
			'std'     => '',
			'desc'    => ''
		);
		$this->settings['social_href_renren'] = array(
			'section' => 'social',
			'title'   => 'Renren',
			'type'    => 'text',
			'std'     => '',
			'desc'    => ''
		);
		$this->settings['social_href_sina-weibo'] = array(
			'section' => 'social',
			'title'   => 'Sina-Weibo',
			'type'    => 'text',
			'std'     => '',
			'desc'    => ''
		);
		$this->settings['social_href_paypal'] = array(
			'section' => 'social',
			'title'   => 'Paypal',
			'type'    => 'text',
			'std'     => '',
			'desc'    => ''
		);
		$this->settings['social_href_picasa'] = array(
			'section' => 'social',
			'title'   => 'Picasa',
			'type'    => 'text',
			'std'     => '',
			'desc'    => ''
		);
		$this->settings['social_href_soundcloud'] = array(
			'section' => 'social',
			'title'   => 'Soundcloud',
			'type'    => 'text',
			'std'     => '',
			'desc'    => ''
		);
		$this->settings['social_href_mixi'] = array(
			'section' => 'social',
			'title'   => 'Mixi',
			'type'    => 'text',
			'std'     => '',
			'desc'    => ''
		);
		$this->settings['social_href_behance'] = array(
			'section' => 'social',
			'title'   => 'Behance',
			'type'    => 'text',
			'std'     => '',
			'desc'    => ''
		);

	}

	public function initialize_settings() {

		$default_settings = array();
		foreach ( $this->settings as $id => $setting ) {
			if ( $setting['type'] != 'heading' )
				$default_settings[$id] = $setting['std'];
		}

		update_option( 'wedding_options', $default_settings );

	}

	public function register_settings() {

		register_setting( 'wedding_options', 'wedding_options', array ( &$this, 'validate_settings' ) );

		foreach ( $this->sections as $slug => $title ) {
				add_settings_section( $slug, $title, array( &$this, 'display_section' ), 'wedding-options' );
		}

		$this->get_options_settings();

		foreach ( $this->settings as $id => $setting ) {
			$setting['id'] = $id;
			$this->create_setting( $setting );
		}

	}

	public function scripts() {
		wp_print_scripts('jquery-ui-tabs');
		if ( ! did_action('wp_enqueue_media') ) wp_enqueue_media();
		wp_enqueue_style('wp-color-picker');
		wp_enqueue_script('wp-color-picker');
		wp_enqueue_script( 'google-webfonts-js', 'http://ajax.googleapis.com/ajax/libs/webfont/1/webfont.js', array( 'jquery') );
		wp_enqueue_script('wedding_admin_options_js', get_template_directory_uri().'/includes/static/options.js');
	}

	public function validate_settings( $input ) {

		if ( ! isset( $input['reset_theme'] ) ) {
			$options = get_option( 'wedding_options' );

			foreach ( $this->checkboxes as $id ) {
				if ( isset( $options[$id] ) && ! isset( $input[$id] ) )
					unset( $options[$id] );
			}

			return $input;
		}
		return false;

	}

}

$theme_options = new Wedding_Options();

function wedding_field( $option ) {
	$options = get_option( 'wedding_options' );
	if ( isset( $options[$option] ) )
		return $options[$option];
	else
		return false;
}
/* Theme Options */

?>